@@ -99,6 +99,71 @@ class CSVWriter(AggDataWriter):
         df.to_csv(path_to_file)
 
 
+class JSONWriter(AggDataWriter):
+    """Class for writing json output."""
+
+    def create_out_file(self) -> None:
+        """Method for writing json files."""
+        # for idx in range(len(self.agg_data)):
+        for idx, (_key, value) in enumerate(self.agg_data.items()):
+            gdf = self.feature
+            # gdf_idx = self.agg_data[idx].id_feature
+            param_values = value.cat_param
+            t_coord = param_values.T_name
+            units = param_values.units
+            varname = param_values.varname
+            time = value.da.coords[t_coord].values
+            # units = self.agg_data[idx].param_dict
+
+            df_key = pd.DataFrame(data=self.vals[idx], columns=gdf.index.T.values)
+
+            df_key.insert(0, "units", [units] * df_key.shape[0])
+            df_key.insert(0, "varname", [varname] * df_key.shape[0])
+            df_key.insert(0, "time", time)
+
+            if idx == 0:
+                df = df_key
+            else:
+                df = pd.concat([df, df_key])
+        df.reset_index(inplace=True)
+        path_to_file = self.outpath / f"{self.fname}.json"
+        print(f"Saving csv file to {path_to_file}")
+        df.to_json(path_to_file, orient="records", date_format="iso")
+
+
+class ParquetWriter(AggDataWriter):
+    """Class for writing csv files."""
+
+    def create_out_file(self) -> None:
+        """Method for writing csv files."""
+        # for idx in range(len(self.agg_data)):
+        for idx, (_key, value) in enumerate(self.agg_data.items()):
+            gdf = self.feature
+            # gdf_idx = self.agg_data[idx].id_feature
+            param_values = value.cat_param
+            t_coord = param_values.T_name
+            units = param_values.units
+            varname = param_values.varname
+            time = value.da.coords[t_coord].values
+            # units = self.agg_data[idx].param_dict
+
+            df_key = pd.DataFrame(data=self.vals[idx], columns=gdf.index.T.values)
+
+            df_key.insert(0, "units", [units] * df_key.shape[0])
+            df_key.insert(0, "varname", [varname] * df_key.shape[0])
+            df_key.insert(0, "time", time)
+
+            if idx == 0:
+                df = df_key
+            else:
+                df = pd.concat([df, df_key])
+        df.reset_index(inplace=True)
+        df.columns = df.columns.map(str)
+        path_to_file = self.outpath / f"{self.fname}.parquet.gzip"
+        print(f"Saving csv file to {path_to_file}")
+        df.to_parquet(path_to_file, compression="gzip")
+
+
 class NetCDFWriter(AggDataWriter):
     """NetCDF writer class."""
 
