@@ -2,6 +2,7 @@
 from typing import Dict
 from typing import List
 from typing import Literal
+from typing import Optional
 from typing import Tuple
 from typing import Type
 from typing import Union
@@ -12,7 +13,9 @@ import numpy.typing as npt
 import pandas as pd
 
 from gdptools.agg.agg_data_writers import CSVWriter
+from gdptools.agg.agg_data_writers import JSONWriter
 from gdptools.agg.agg_data_writers import NetCDFWriter
+from gdptools.agg.agg_data_writers import ParquetWriter
 from gdptools.agg.agg_engines import DaskAgg
 from gdptools.agg.agg_engines import ParallelAgg
 from gdptools.agg.agg_engines import SerialAgg
@@ -41,6 +44,8 @@ AGGENGINES = Literal["serial", "parallel", "dask"]
 """ List of aggregation methods.
 
 serial: performes weighted-area aggregation by iterating through polygons.
+parallel: performes weighted-area aggregation by number of jobs.
+dask: performs weighted-area aggregation in the presence of a dask client.
 
 TODO: parallel
 
@@ -51,11 +56,14 @@ Returns:
     _type_: str
 """
 
-AGGWRITERS = Literal["csv", "netcdf"]
+AGGWRITERS = Literal["none", "csv", "parquet", "netcdf", "json"]
 """ List of available writers applied to the aggregation.
 
+none: Output not writte n to a file.
 csv: Output data in csv format.
+parquet: Output data to parquet.gzip file.
 netcdf: Output data in netcdf format.
+json: Output data as json.
 
 Raises:
     TypeError: If supplied attribute is not one of AGGWRITERS.
@@ -75,12 +83,14 @@ class AggGen:
         agg_engine: AGGENGINES,
         agg_writer: AGGWRITERS,
         weights: Union[str, pd.DataFrame],
-        out_path: str,
-        file_prefix: str,
-        append_date: bool = False,
-        jobs: int = -1,
+        out_path: Optional[Union[str, None]] = None,
+        file_prefix: Optional[Union[str, None]] = None,
+        append_date: Optional[bool] = False,
+        jobs: Optional[int] = -1,
     ) -> None:
-        """Initialize AggGen.
+        """__init__ Initalize AggGen.
+
+        _extended_summary_
 
         Args:
             user_data (UserData): _description_
@@ -88,15 +98,10 @@ class AggGen:
             agg_engine (AGGENGINES): _description_
             agg_writer (AGGWRITERS): _description_
             weights (Union[str, pd.DataFrame]): _description_
-            out_path (str): _description_
-            file_prefix (str): _description_
-            append_date (bool): _description_. Defaults to False.
-            jobs (int): _description_. Defaults to -1
-
-        Raises:
-            TypeError: _description_
-            TypeError: _description_
-            TypeError: _description_
+            out_path (Optional[Union[str, None]], optional): _description_. Defaults to None.
+            file_prefix (Optional[Union[str, None]], optional): _description_. Defaults to None.
+            append_date (Optional[bool], optional): _description_. Defaults to False.
+            jobs (Optional[int], optional): _description_. Defaults to -1.
         """
         self._user_data = user_data
         self._stat_method = stat_method
@@ -109,14 +114,32 @@ class AggGen:
         self._jobs = jobs
         self._agg_data: Dict[str, AggData]
 
-        self._stat: Union[Type[MAWeightedAverage], Type[WeightedAverage]]
-        if self._stat_method == "masked_average":
-            self._stat = MAWeightedAverage
-        elif self._stat_method == "average":
-            self._stat = WeightedAverage
-        else:
-            raise TypeError(f"stat_method: {self._stat_method} not in {STATSMETHODS}")
+        self._set_stats_method()
+        self._set_agg_engine()
+        self._set_writer()
 
+    def _set_writer(self):
+        if self._agg_writer != "none" and (
+            (self._out_path is None) or (self._file_prefix is None)
+        ):
+            raise ValueError(
+                f"If agg_writer not none, then out_path: {self._out_path}"
+                f" and file_prefix: {self._file_prefix} must be set."
+            )
+
+        self.__writer: Union[Type[CSVWriter], Type[ParquetWriter], Type[NetCDFWriter]]
+        if self._agg_writer == "csv":
+            self.__writer = CSVWriter
+        elif self._agg_writer == "parquet":
+            self.__writer = ParquetWriter
+        elif self._agg_writer == "netcdf":
+            self.__writer = NetCDFWriter
+        elif self._agg_writer == "json":
+            self.__writer = JSONWriter
+        else:
+            raise TypeError(f"agg_writer: {self._agg_writer} not in {AGGWRITERS}")
+
+    def _set_agg_engine(self):
         self.agg: Union[Type[SerialAgg], Type[ParallelAgg], Type[DaskAgg]]
         if self._agg_engine == "serial":
             self.agg = SerialAgg
@@ -127,13 +150,14 @@ class AggGen:
         else:
             raise TypeError(f"agg_engine: {self._agg_engine} not in {AGGENGINES}")
 
-        self.__writer: Union[Type[CSVWriter], Type[NetCDFWriter]]
-        if self._agg_writer == "csv":
-            self.__writer = CSVWriter
-        elif self._agg_writer == "netcdf":
-            self.__writer = NetCDFWriter
+    def _set_stats_method(self):
+        self._stat: Union[Type[MAWeightedAverage], Type[WeightedAverage]]
+        if self._stat_method == "masked_average":
+            self._stat = MAWeightedAverage
+        elif self._stat_method == "average":
+            self._stat = WeightedAverage
         else:
-            raise TypeError(f"agg_writer: {self._agg_writer} not in {AGGWRITERS}")
+            raise TypeError(f"stat_method: {self._stat_method} not in {STATSMETHODS}")
 
     def calculate_agg(
         self,
@@ -149,14 +173,15 @@ class AggGen:
             stat=self._stat,
             jobs=self._jobs,
         )
-        self.__writer().save_file(
-            agg_data=self._agg_data,
-            feature=new_gdf,
-            vals=agg_vals,
-            p_out=self._out_path,
-            file_prefix=self._file_prefix,
-            append_date=self._append_date,
-        )
+        if self._agg_writer != "none":
+            self.__writer().save_file(
+                agg_data=self._agg_data,
+                feature=new_gdf,
+                vals=agg_vals,
+                p_out=self._out_path,
+                file_prefix=self._file_prefix,
+                append_date=self._append_date,
+            )
 
         return new_gdf, agg_vals
 
