@@ -23,7 +23,6 @@ from gdptools.helpers import build_subset_tiff
 from gdptools.utils import _check_for_intersection
 from gdptools.utils import _check_for_intersection_nc
 from gdptools.utils import _get_cells_poly
-from gdptools.utils import _get_crs
 from gdptools.utils import _get_data_via_catalog
 from gdptools.utils import _get_geodataframe
 from gdptools.utils import _get_rxr_dataset
@@ -79,6 +78,18 @@ class ODAPCatData(UserData):
     ) -> None:
         """Initialize PrepODAPCatData class.
 
+        This class uses a parameter and grid json catalog developed by Mike Johnson
+        and available here:
+
+        Param: https://mikejohnson51.github.io/opendap.catalog/cat_params.json
+        Grids: https://mikejohnson51.github.io/opendap.catalog/cat_grids.json
+
+        These can be queried in pandas to return the dictionary associated with a
+        specific source and variable as in the OPENDaP Catalog examples. The param_dict
+        and grid_dict arguments are composed of a key defined by the variable name
+        and a dictionary of the corresponding param and grid json string from the
+        OPENDaP Catelog.
+
         Args:
             param_dict (dict[str, dict]): Parameter metadata from OPeNDAP catalog.
             grid_dict (dict[str, dict]): Grid metadata from OPeNDAP catalog.
@@ -110,7 +121,7 @@ class ODAPCatData(UserData):
         self.gdf, self.gdf_bounds = _get_shp_file(
             shp_file=self.gdf, cat_grid=cg, is_degrees=is_degrees
         )
-        self.rotate_ds = bool((not is_intersect) & is_degrees & (not is_0_360))
+        self.rotate_ds = bool((not is_intersect) & is_degrees & (is_0_360))
 
     def get_feature_id(self) -> str:
         """Return id_feature."""
@@ -237,7 +248,6 @@ class UserCatData(UserData):
 
         Raises:
             TypeError: _description_
-            ValueError: _description_
         """
         logger.info("Initializing UserCatData")
         logger.info("  - loading data")
@@ -252,11 +262,7 @@ class UserCatData(UserData):
         if not isinstance(var, List):
             raise TypeError(f"Input var {var} should be a list of variables")
         self.var = var
-        tcrs = _get_crs(self.f_feature.crs)
         self.proj_feature = proj_feature
-        spcrs = _get_crs(self.proj_feature)
-        if tcrs != spcrs:
-            raise ValueError(f"f_feature.crs {tcrs} not equal to proj.feature {spcrs}")
         self.id_feature = id_feature
 
         self.gdf_bounds = _get_shp_bounds_w_buffer(
@@ -275,7 +281,7 @@ class UserCatData(UserData):
             gdf=self.f_feature,
         )
 
-        if bool((not is_intersect) & is_degrees & (not is_0_360)):  # rotate
+        if bool((not is_intersect) & is_degrees & (is_0_360)):  # rotate
             logger.info("  - rotating into -180 - 180")
             self.ds.coords[self.x_coord] = (
                 self.ds.coords[self.x_coord] + 180
