@@ -57,8 +57,8 @@ def _reproject_for_weight_calc(
 ) -> Tuple[gpd.GeoDataFrame, gpd.GeoDataFrame]:
     start = time.perf_counter()
     # grid_cells.set_crs(grid_in_crs, inplace=True)
-    grid_cells.to_crs(grid_out_crs, inplace=True)
-    poly.to_crs(grid_out_crs, inplace=True)
+    grid_cells = grid_cells.to_crs(grid_out_crs)
+    poly = poly.to_crs(grid_out_crs)
     end = time.perf_counter()
     print(
         f"Reprojecting to epsg:{wght_gen_crs} finished in {round(end-start, 2)}"
@@ -383,6 +383,7 @@ def _get_shp_file(
     gdf = shp_file.to_crs(cat_grid.proj)
     # buffer polygons bounding box by twice max resolution of grid
     bbox = box(*gdf.total_bounds)
+    # if
     gdf_bounds = bbox.buffer(2.0 * max(cat_grid.resX, cat_grid.resY)).bounds  # type: ignore
     if is_degrees and (gdf_bounds[0] < -180.0) & (gdf_bounds[2] > 180.0):
         newxmax = 180.0 - (abs(gdf_bounds[0]) - 180.0)
@@ -463,19 +464,28 @@ def _get_shp_bounds_w_buffer(
     lon: str,
     lat: str,
 ) -> npt.NDArray[np.double]:
-    """Return bounding box based on 2 * max(ds.dx, ds.dy).
+    """_get_shp_bounds_w_buffer Return bounding box based on 2 * max(ds.dx, ds.dy).
+
+    _extended_summary_
 
     Args:
         gdf (gpd.GeoDataFrame): _description_
-        ds (xr.Dataset): _description_
+        ds (Union[xr.DataArray, xr.Dataset]): _description_
         crs (Any): _description_
         lon (str): _description_
         lat (str): _description_
 
+    Raises:
+        ValueError: _description_
+
     Returns:
-        tuple: _description_
+        npt.NDArray[np.double]: _description_
     """
     bbox = box(*gdf.to_crs(crs).total_bounds)
+    if bbox.area == np.nan:
+        raise ValueError(
+            f"unable to reproject f_feature's projection {gdf.crs} to proj_ds{crs}"
+        )
     return np.asarray(
         bbox.buffer(
             2 * max(max(np.diff(ds[lat].values)), max(np.diff(ds[lon].values)))  # type: ignore
@@ -526,7 +536,7 @@ def _check_for_intersection(
                 "0-360 longitude crossing the international date line encountered.\n"
                 "Longitude coordinates will be 0-360 in output."
             )
-            warnings.warn(warning_string)
+            warnings.warn(warning_string, stacklevel=2)
 
     return is_intersect, is_degrees, is_0_360
 
@@ -577,7 +587,7 @@ def _check_for_intersection_nc(
                 "0-360 longitude crossing the international date line encountered.\n"
                 "Longitude coordinates will be 0-360 in output."
             )
-            warnings.warn(warning_string)
+            warnings.warn(warning_string, stacklevel=2)
 
     return is_intersect, is_degrees, is_0_360
 
