@@ -79,7 +79,7 @@ class CalcWeightEngine(ABC):
         _check_feature_crs(poly=self.poly)
         _check_grid_cell_crs(grid_cells=self.grid_cells)
         self.grid_out_crs = _get_crs(self.wght_gen_crs)
-        _reproject_for_weight_calc(
+        self.poly, self.grid_cells = _reproject_for_weight_calc(
             poly=self.poly,
             grid_cells=self.grid_cells,
             grid_out_crs=self.grid_out_crs,
