@@ -536,10 +536,29 @@ def test_odapcatdata_s(
     _ngdf2, nvals2 = gen_agg2.calculate_agg()
     np.testing.assert_allclose(aet_average, nvals2[0], rtol=1e-4, verbose=True)
 
+    tmpdir3 = TemporaryDirectory()
+    gen_agg3 = AggGen(
+        user_data=user_data,
+        stat_method="average",
+        agg_engine="serial",
+        agg_writer="parquet",
+        weights=tmpfile.name,
+        out_path=tmpdir3.name,
+        file_prefix="test_agg_gen3",
+    )
+
+    _ngdf3, nvals3 = gen_agg3.calculate_agg()
+    np.testing.assert_allclose(aet_average, nvals3[0], rtol=1e-4, verbose=True)
+
     file = Path(tmpdir.name) / "test_agg_gen.nc"
     assert file.exists()
-    file = Path(tmpdir2.name) / "test_agg_gen2.csv"
-    assert file.exists()
+    file2 = Path(tmpdir2.name) / "test_agg_gen2.csv"
+    assert file2.exists()
+    file3 = Path(tmpdir3.name) / "test_agg_gen3.parquet.gzip"
+    assert file3.exists()
+
+    pq = pd.read_parquet(file3)
+    assert isinstance(pq, pd.DataFrame)
 
 
 @pytest.fixture()
@@ -572,7 +591,7 @@ def get_out_path(tmp_path: Path) -> Path:
     return tmp_path
 
 
-data_crs = 4326
+data_crs = 4326  # "crs84"
 x_coord = "lon"
 y_coord = "lat"
 t_coord = "day"
@@ -614,11 +633,25 @@ def test_usercatdata(
 
     wghts = weight_gen.calculate_weights()
 
+    user_data2 = UserCatData(
+        ds=get_xarray,
+        proj_ds=data_crs,
+        x_coord=x_coord,
+        y_coord=y_coord,
+        t_coord=t_coord,
+        var=tvar,
+        f_feature=get_gdf,
+        proj_feature=shp_crs,
+        id_feature=shp_poly_idx,
+        period=[sdate, edate],
+    )
+
     weight_gen2 = WeightGen(
-        user_data=user_data,
+        user_data=user_data2,
         method="parallel",
         output_file=tmpfile.name,
         weight_gen_crs=wght_gen_crs,
+        jobs=2,
     )
 
     _wghts2 = weight_gen2.calculate_weights()  # noqa: F841
@@ -626,27 +659,41 @@ def test_usercatdata(
     tmpdir = TemporaryDirectory()
 
     agg_gen = AggGen(
-        user_data=user_data,
+        user_data=user_data2,
         stat_method="average",
         agg_engine="serial",
         agg_writer="csv",
         weights=wghts,
         out_path=tmpdir.name,
         file_prefix="test_agg_gen_2",
+        jobs=2,
     )
 
     _ngdf, _nvals = agg_gen.calculate_agg()
     print(_nvals[0])
 
+    user_data3 = UserCatData(
+        ds=get_xarray,
+        proj_ds=data_crs,
+        x_coord=x_coord,
+        y_coord=y_coord,
+        t_coord=t_coord,
+        var=tvar,
+        f_feature=get_gdf,
+        proj_feature=shp_crs,
+        id_feature=shp_poly_idx,
+        period=[sdate, edate],
+    )
     tmpdir2 = TemporaryDirectory()
     agg_gen = AggGen(
-        user_data=user_data,
+        user_data=user_data3,
         stat_method="masked_average",
         agg_engine="serial",
         agg_writer="netcdf",
         weights=wghts,
         out_path=tmpdir2.name,
         file_prefix="test_agg_gen_2",
+        jobs=2,
     )
 
     _ngdf, _nvals = agg_gen.calculate_agg()
